lilypondfiletools.BookBlock
===========================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.format

   .. note:: Inherited from :py:class:`lilypondfiletools._NonattributedBlock <abjad.tools.lilypondfiletools._NonattributedBlock._NonattributedBlock._NonattributedBlock>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.is_formatted_when_empty

   .. note:: Inherited from :py:class:`lilypondfiletools._NonattributedBlock <abjad.tools.lilypondfiletools._NonattributedBlock._NonattributedBlock._NonattributedBlock>`

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.append

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.count

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.extend

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.index

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.insert

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.pop

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.remove

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.reverse

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.sort

   .. note:: Inherited from `__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__add__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__contains__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__delitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__delslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__eq__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__ge__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__getitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__getslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__gt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__iadd__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__imul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__iter__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__le__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__len__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__lt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__mul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__ne__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__repr__

   .. note:: Inherited from :py:class:`lilypondfiletools._NonattributedBlock <abjad.tools.lilypondfiletools._NonattributedBlock._NonattributedBlock._NonattributedBlock>`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__reversed__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__rmul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__setitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__setslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookBlock.BookBlock.BookBlock.__str__

   .. note:: Inherited from `__builtin__.object`
